@@ -2,12 +2,13 @@
 function (object, resp.patterns = NULL, order = TRUE, ...) {
     if (!inherits(object, "grm"))
         stop("Use only with 'grm' objects.\n")
+    if (any(is.na(object$X)))
+        warning("residuals are not meaningful for patterns with missing data.\n")
     fits <- fitted(object, resp.patterns = resp.patterns)
     X <- fits[, -ncol(fits), drop = FALSE]
     Exp <- fits[, "Exp"]
-    betas <- object$coefficients
-    vals <- lapply(betas, function(x) seq(1, length(x) - 1)) 
-    Obs <- observedFreqs(object, X, vals)
+    betas <- object$coefficients 
+    Obs <- observedFreqs(object, X)
     out <- cbind(X, Obs = Obs, Exp = Exp, Resid = round((Obs - Exp) / sqrt(Exp), 3))
     if (order)
         out <- out[order(out[, "Resid"]), ]
